# Core Package

The core package provides fundamental functionality for FDTD simulations.

## Components

- [Types](types.md) - Shape and slice type definitions
- [Configuration](config.md) - Simulation and gradient configuration
- [PyTree Utilities](pytree.md) - Tree class utilities and fields
- [JAX Utilities](jax.md) - JAX-specific utilities
- [Array Operations](arrays.md) - Array manipulation functions
- [Distributed Computing](distributed.md) - Sharding and distributed computation
